@@ -1,6 +1,7 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+#include <QtCore/QSettings>
 #include <QtGui/QMainWindow>
 #include <QtGui/QMessageBox>
 
@@ -17,14 +18,22 @@ class MainWindow : public QMainWindow
 public:
     explicit MainWindow(QWidget *parent = 0);
     ~MainWindow();
+    void showTip();
 public slots:
     void about();
+    void regenAppList();
 protected:
     void changeEvent(QEvent *e);
 
+private slots:
+    void updateSettings();
+    void email();
+    void support();
+    void addGame();
 private:
     Ui::MainWindow *ui;
     QVector<MainWindowLine*> mwlines;
+    QSettings settings;
 };
 
 #endif // MAINWINDOW_H
